@@ -11,10 +11,16 @@ Python Interface to Cologne Digital Sanskrit Lexicon (CDSL).
 
 __author__ = "Hrishikesh Terdalkar"
 __email__ = 'hrishikeshrt@linuxmail.org'
-__version__ = '0.3.3'
+__version__ = '0.4.0'
 
 ###############################################################################
 
-from .models import DEFAULT_SCHEME, INTERNAL_SCHEME    # noqa
-from .pycdsl import CDSLDict, CDSLCorpus               # noqa
-from .shell import CDSLShell                           # noqa
\ No newline at end of file
+from .corpus import CDSLCorpus               # noqa
+from .lexicon import CDSLDict                # noqa
+from .shell import CDSLShell                 # noqa
+from .constants import (                     # noqa
+    SERVER_URL,
+    DEFAULT_SCHEME, INTERNAL_SCHEME,
+    DEFAULT_CORPUS_DIR,
+    DEFAULT_DICTIONARIES, ENGLISH_DICTIONARIES
+)
